==> fannypack-2.2.0.tgz: package/es/Divider/styled.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  &::before {\n    background: white;\n    color: #c3c3c3;\n    content: \'', '\';\n    text-transform: uppercase;\n    font-size: 0.7em;\n    font-weight: bold;\n    padding: 0.2rem 0.5rem;\n\n    & {\n      ', '\n    }\n  }\n'], ['\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  &::before {\n    background: white;\n    color: #c3c3c3;\n    content: \'', '\';\n    text-transform: uppercase;\n    font-size: 0.7em;\n    font-weight: bold;\n    padding: 0.2rem 0.5rem;\n\n    & {\n      ', '\n    }\n  }\n']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n  height: auto;\n\n  & {\n    ', ';\n  }\n'], ['\n  height: auto;\n\n  & {\n    ', ';\n  }\n']),
    _templateObject3 = _taggedTemplateLiteralLoose(['\n  opacity: 1;\n  border-color: #e7e9ed;\n\n  & {\n    ', ' /**/\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  opacity: 1;\n  border-color: #e7e9ed;\n\n  & {\n    ', ' /**/\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']);

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import Divider from 'reakit/Divider';
import styled, { css } from 'reakit/styled';
import { theme } from 'styled-tools';

var contentAttributes = css(_templateObject, function (props) {
  return props.content;
}, theme('Divider.content'));
var verticalAttributes = css(_templateObject2, theme('Divider.vertical'));

export default styled(Divider)(_templateObject3, function (props) {
  return props.content && contentAttributes;
}, function (props) {
  return props.vertical && verticalAttributes;
}, theme('Divider.base'));

==> fannypack-2.8.0.tgz: package/es/Divider/styled.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  &::before {\n    background: white;\n    color: #c3c3c3;\n    content: \'', '\';\n    text-transform: uppercase;\n    font-size: 0.7em;\n    font-weight: bold;\n    padding: 0.2rem 0.5rem;\n\n    & {\n      ', '\n    }\n  }\n'], ['\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  &::before {\n    background: white;\n    color: #c3c3c3;\n    content: \'', '\';\n    text-transform: uppercase;\n    font-size: 0.7em;\n    font-weight: bold;\n    padding: 0.2rem 0.5rem;\n\n    & {\n      ', '\n    }\n  }\n']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n  height: auto;\n\n  & {\n    ', ';\n  }\n'], ['\n  height: auto;\n\n  & {\n    ', ';\n  }\n']),
    _templateObject3 = _taggedTemplateLiteralLoose(['\n  opacity: 1;\n  border-color: #e7e9ed;\n\n  & {\n    ', ' /**/\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  opacity: 1;\n  border-color: #e7e9ed;\n\n  & {\n    ', ' /**/\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']);

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import Divider from 'reakit/Divider';
import styled, { css } from 'reakit/styled';
import { theme } from 'styled-tools';

var contentProperties = css(_templateObject, function (props) {
  return props.content;
}, theme('Divider.content'));
var verticalProperties = css(_templateObject2, theme('Divider.vertical'));

export default styled(Divider)(_templateObject3, function (props) {
  return props.content && contentProperties;
}, function (props) {
  return props.vertical && verticalProperties;
}, theme('Divider.base'));
